#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class ADXBreakoutsIndicator : Indicator
	{
		private double currentPrice;
		private bool signalValid;
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"ADX Breakouts - The ADX signal line goes up whenever volatility increases. When ADX gets over 40, it shows especially strong breakout price action in progress.";
				Name										= "ADXBreakoutsIndicator";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= true;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				ADXPeriod									= 15;
				ADXBO										= 40;
				PntAbvDlyHi									= 0.5;
				ADXBreakoutSignalMessage					= @"ADX Breakout";
				ArrowBrush									= Brushes.LimeGreen;
			}
			else if (State == State.Configure)
			{
			}
			else if (State == State.DataLoaded)
			{
				currentPrice = 0;
				signalValid = true;
			}
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar < ADXPeriod) return;
			
			// Condition for ADX Breakout Entries
            if (ADX(ADXPeriod)[0] > ADXBO && signalValid && High[0] >= CurrentDayOHL().CurrentHigh[1] + PntAbvDlyHi)
			{
				Draw.ArrowDown(this, "Entry Trigger Signal" + Time[0], true, 0, High[0] + 1, ArrowBrush);
				Draw.Text(this, "Breakout Entry Text" + ToTime(Time[0]), true, ADXBreakoutSignalMessage, 0, High[0] + 2, 0, Brushes.Black, new SimpleFont("Arial", 8), TextAlignment.Center, Brushes.Transparent, Brushes.Transparent, 1);	
				signalValid = false;
			}
			
		    if(!signalValid && ADX(ADXPeriod)[0] < ADXBO )
			{
				signalValid = true;
			}
		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="ADXPeriod", Description="Value for ADX Period", Order=1, GroupName="Parameters")]
		public int ADXPeriod
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="ADXBO", Description="ADX Break Out Value", Order=2, GroupName="Parameters")]
		public int ADXBO
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0.01, double.MaxValue)]
		[Display(Name="PntAbvDlyHi", Description="Point value above daily high", Order=3, GroupName="Parameters")]
		public double PntAbvDlyHi
		{ get; set; }

		[NinjaScriptProperty]
		[Display(Name="ADXBreakoutSignalMessage", Description="ADX Breakout Signal Message", Order=4, GroupName="Parameters")]
		public string ADXBreakoutSignalMessage
		{ get; set; }

		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(Name="ArrowBrush", Description="Color for Breakout Entry Signal Arrow", Order=5, GroupName="Parameters")]
		public Brush ArrowBrush
		{ get; set; }

		[Browsable(false)]
		public string ArrowBrushSerializable
		{
			get { return Serialize.BrushToString(ArrowBrush); }
			set { ArrowBrush = Serialize.StringToBrush(value); }
		}			
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private ADXBreakoutsIndicator[] cacheADXBreakoutsIndicator;
		public ADXBreakoutsIndicator ADXBreakoutsIndicator(int aDXPeriod, int aDXBO, double pntAbvDlyHi, string aDXBreakoutSignalMessage, Brush arrowBrush)
		{
			return ADXBreakoutsIndicator(Input, aDXPeriod, aDXBO, pntAbvDlyHi, aDXBreakoutSignalMessage, arrowBrush);
		}

		public ADXBreakoutsIndicator ADXBreakoutsIndicator(ISeries<double> input, int aDXPeriod, int aDXBO, double pntAbvDlyHi, string aDXBreakoutSignalMessage, Brush arrowBrush)
		{
			if (cacheADXBreakoutsIndicator != null)
				for (int idx = 0; idx < cacheADXBreakoutsIndicator.Length; idx++)
					if (cacheADXBreakoutsIndicator[idx] != null && cacheADXBreakoutsIndicator[idx].ADXPeriod == aDXPeriod && cacheADXBreakoutsIndicator[idx].ADXBO == aDXBO && cacheADXBreakoutsIndicator[idx].PntAbvDlyHi == pntAbvDlyHi && cacheADXBreakoutsIndicator[idx].ADXBreakoutSignalMessage == aDXBreakoutSignalMessage && cacheADXBreakoutsIndicator[idx].ArrowBrush == arrowBrush && cacheADXBreakoutsIndicator[idx].EqualsInput(input))
						return cacheADXBreakoutsIndicator[idx];
			return CacheIndicator<ADXBreakoutsIndicator>(new ADXBreakoutsIndicator(){ ADXPeriod = aDXPeriod, ADXBO = aDXBO, PntAbvDlyHi = pntAbvDlyHi, ADXBreakoutSignalMessage = aDXBreakoutSignalMessage, ArrowBrush = arrowBrush }, input, ref cacheADXBreakoutsIndicator);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.ADXBreakoutsIndicator ADXBreakoutsIndicator(int aDXPeriod, int aDXBO, double pntAbvDlyHi, string aDXBreakoutSignalMessage, Brush arrowBrush)
		{
			return indicator.ADXBreakoutsIndicator(Input, aDXPeriod, aDXBO, pntAbvDlyHi, aDXBreakoutSignalMessage, arrowBrush);
		}

		public Indicators.ADXBreakoutsIndicator ADXBreakoutsIndicator(ISeries<double> input , int aDXPeriod, int aDXBO, double pntAbvDlyHi, string aDXBreakoutSignalMessage, Brush arrowBrush)
		{
			return indicator.ADXBreakoutsIndicator(input, aDXPeriod, aDXBO, pntAbvDlyHi, aDXBreakoutSignalMessage, arrowBrush);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.ADXBreakoutsIndicator ADXBreakoutsIndicator(int aDXPeriod, int aDXBO, double pntAbvDlyHi, string aDXBreakoutSignalMessage, Brush arrowBrush)
		{
			return indicator.ADXBreakoutsIndicator(Input, aDXPeriod, aDXBO, pntAbvDlyHi, aDXBreakoutSignalMessage, arrowBrush);
		}

		public Indicators.ADXBreakoutsIndicator ADXBreakoutsIndicator(ISeries<double> input , int aDXPeriod, int aDXBO, double pntAbvDlyHi, string aDXBreakoutSignalMessage, Brush arrowBrush)
		{
			return indicator.ADXBreakoutsIndicator(input, aDXPeriod, aDXBO, pntAbvDlyHi, aDXBreakoutSignalMessage, arrowBrush);
		}
	}
}

#endregion
