#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.Indicators;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Strategies in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Strategies
{
	public class ADXBreakoutStrategy : Strategy
	{
		private bool signalValid;
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"ADX Breakouts - The ADX signal line goes up whenever volatility increases. When ADX gets over 40, it shows especially strong breakout price action in progress.";
				Name										= "ADXBreakoutStrategy";
				Calculate									= Calculate.OnBarClose;
				EntriesPerDirection							= 1;
				EntryHandling								= EntryHandling.AllEntries;
				IsExitOnSessionCloseStrategy				= false;
				ExitOnSessionCloseSeconds					= 30;
				IsFillLimitOnTouch							= false;
				MaximumBarsLookBack							= MaximumBarsLookBack.TwoHundredFiftySix;
				OrderFillResolution							= OrderFillResolution.Standard;
				Slippage									= 0;
				StartBehavior								= StartBehavior.WaitUntilFlat;
				TimeInForce									= TimeInForce.Gtc;
				TraceOrders									= false;
				RealtimeErrorHandling						= RealtimeErrorHandling.StopCancelClose;
				StopTargetHandling							= StopTargetHandling.PerEntryExecution;
				BarsRequiredToTrade							= 20;
				// Disable this property for performance gains in Strategy Analyzer optimizations
				// See the Help Guide for additional information
				IsInstantiatedOnEachOptimizationIteration	= true;
				ADXPeriod									= 14;
				ADXBO										= 40;
				PntAbvDlyHi									= 0.5;
				PointStopLoss								= 2;
				ADXLineValueLower							= 20;
				ADXLineValueUpper							= 1;
				ADXBreakoutSignalMessage					= @"ADX Breakout";
				ArrowBrush									= Brushes.LimeGreen;
			}
			else if (State == State.Configure)
			{
				SetTrailStop(CalculationMode.Ticks, PointStopLoss);
			}
			else if (State == State.DataLoaded)
			{
				signalValid = true;
				
				AddChartIndicator(ADXBreakoutsIndicator(ADXPeriod, ADXBO, PntAbvDlyHi, ADXBreakoutSignalMessage, ArrowBrush));
				AddChartIndicator(ADX(ADXPeriod));
				AddChartIndicator(VolumeUpDown());
			}
		}

		protected override void OnBarUpdate()
		{
			//if(Position.MarketPosition == MarketPosition.Flat)
			//	SetTrailStop(CalculationMode.Ticks, PointStopLoss);
			
			if (CurrentBar < ADXPeriod) return;	
				
            // Condition for ADX Breakout Entry Signals
            if (ADX(ADXPeriod)[0] > ADXBO && Close[0] >= CurrentDayOHL().CurrentHigh[1] + PntAbvDlyHi && signalValid)
			{
//				EnterLong(DefaultQuantity,"Breakout Entry Long");
				
				Draw.ArrowUp(this, "LongEntry" + CurrentBar, true, 0, Low[0] - TickSize, Brushes.DodgerBlue);
				SetTrailStop(CalculationMode.Ticks, PointStopLoss*(Instrument.MasterInstrument.PointValue/(Instrument.MasterInstrument.PointValue * TickSize)));
				signalValid = false;
			}
			
			else if (ADX(ADXPeriod)[0] > ADXBO && Close[0] <= CurrentDayOHL().CurrentLow[1] - PntAbvDlyHi && signalValid)
			{
//				EnterShort(DefaultQuantity,"Breakout Entry Short");
				Draw.ArrowDown(this, "ShortEntry" + CurrentBar, true, 0, High[0] + TickSize, Brushes.HotPink);
				SetTrailStop(CalculationMode.Ticks, PointStopLoss*(Instrument.MasterInstrument.PointValue/(Instrument.MasterInstrument.PointValue * TickSize)));
				signalValid = false;
			}
			
			
			if(!signalValid && ADX(ADXPeriod)[0] < ADXBO)
			{
				signalValid = true;
			}
		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(ResourceType = typeof(Custom.Resource), Name="ADXPeriod", Description="Value for ADX Period", Order=1, GroupName="NinjaScriptStrategyParameters")]
		public int ADXPeriod
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(ResourceType = typeof(Custom.Resource), Name="ADXBO", Description="Value for ADX", Order=2, GroupName="NinjaScriptStrategyParameters")]
		public int ADXBO
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0.01, double.MaxValue)]
		[Display(ResourceType = typeof(Custom.Resource), Name="PntAbvDlyHi", Description="Point value above daily high", Order=3, GroupName="NinjaScriptStrategyParameters")]
		public double PntAbvDlyHi
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(ResourceType = typeof(Custom.Resource), Name="PointStopLoss", Description="Point value for stop loss", Order=4, GroupName="NinjaScriptStrategyParameters")]
		public int PointStopLoss
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, double.MaxValue)]
		[Display(ResourceType = typeof(Custom.Resource), Name="ADXLineValueLower", Description="Value for ADX Lower Line", Order=5, GroupName="NinjaScriptStrategyParameters")]
		public double ADXLineValueLower
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, double.MaxValue)]
		[Display(ResourceType = typeof(Custom.Resource), Name="ADXLineValueUpper", Description="Value for ADX Upper Line", Order=6, GroupName="NinjaScriptStrategyParameters")]
		public double ADXLineValueUpper
		{ get; set; }

		[NinjaScriptProperty]
		[Display(ResourceType = typeof(Custom.Resource), Name="ADXBreakoutSignalMessage", Description="ADX Breakout Signal Message", Order=7, GroupName="NinjaScriptStrategyParameters")]
		public string ADXBreakoutSignalMessage
		{ get; set; }

		[NinjaScriptProperty]
		[XmlIgnore]
		[Display(ResourceType = typeof(Custom.Resource), Name="ArrowBrush", Description="Color for Breakout Entry Signal Arrow", Order=8, GroupName="NinjaScriptStrategyParameters")]
		public Brush ArrowBrush
		{ get; set; }

		[Browsable(false)]
		public string ArrowBrushSerializable
		{
			get { return Serialize.BrushToString(ArrowBrush); }
			set { ArrowBrush = Serialize.StringToBrush(value); }
		}			
		#endregion

	}
}
